package net.knarcraft.minecraftserverlauncher.server.servertypes;

import java.io.File;
import java.io.IOException;
import java.nio.file.Paths;

import static net.knarcraft.minecraftserverlauncher.utility.CommonFunctions.downloadFile;
import static net.knarcraft.minecraftserverlauncher.utility.CommonFunctions.readFile;
import static net.knarcraft.minecraftserverlauncher.utility.CommonFunctions.stringBetween;

public class BungeeCord extends AbstractServerType {

    private String versionURL;
    private String lastVersion;
    private String srcStart;
    private String srcEnd;

    /**
     * Instantiates a new BungeeCord server type
     *
     * @param typeName <p>The name of the server type</p>
     * @param versions <p>The available versions for the server type</p>
     * @param versionURL <p>The URL used to finding the newest version</p>
     * @param srcStart <p>The string after which the version id starts</p>
     * @param srcEnd <p>The string marking the end of the version id</p>
     * @param downloadURL <p>The URL used for downloading the latest version</p>
     */
    public BungeeCord(String typeName, String[] versions, String versionURL, String srcStart, String srcEnd, String downloadURL) {
        super(typeName, versions, downloadURL);
        this.versionURL = versionURL;
        this.srcStart = srcStart;
        this.srcEnd = srcEnd;
    }

    @Override
    public boolean downloadJar(String folder, String version) throws IOException {
        String file = this.getName() + version + ".jar";
        File filePath = new File(folder + file);
        String newestVersion = stringBetween(readFile(versionURL), srcStart, srcEnd);
        String oldVersion = lastVersion;
        lastVersion = newestVersion;
        return (filePath.isFile() && newestVersion.equals(oldVersion)) || downloadFile(downloadURL, Paths.get(filePath.toURI()));
    }
}
